
.. py:currentmodule:: pythreejs

InstancedBufferGeometry
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: InstancedBufferGeometry()
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.BufferGeometry`.

    Three.js docs: https://threejs.org/docs/#api/core/InstancedBufferGeometry


    .. py:attribute:: maxInstancedCount

        .. sourcecode:: python

            CInt(None, allow_none=True).tag(sync=True)

